/******************************************************************************/
/*                                                                            */
/* 名    称 :   ＡｌａｒｍＲｅｃｅｉｖｅｒ．ｊａｖａ                          */
/*                                                                            */
/* 機    能 :  エレキジャック特設記事用サンプルプログラム。                   */
/*                                                                            */
/* ＣＱ出版 エレキジャック  特設記事  *********************************       */
/*                                                                            */
/*       ■■■■■■■■■■■■■■■■■■■■■■■■■■■■             */
/*       ■■■■■                                    ■■■■■             */
/*       ■■■■■  ＨＩＤマイコンデバイスとつなぐ    ■■■■■             */
/*       ■■■■■                                    ■■■■■             */
/*       ■■■■■■■■■■■■■■■■■■■■■■■■■■■■             */
/*                                                                            */
/*                                                                            */
/* 【プログラムの運転概要】                                                   */
/*  このクラスはアラームマネージャにより定期的に呼び出されて処理を実行します。*/
/*                                                                            */
/*  実装されている処理は下記の通りです。                                      */
/*                                                                            */
/*  SharedPreferences（アプリ・クラス間共有ファイル）にメインで記録されている */
/*  ＨＩＤデバイスからのデータを読み込みます。                                */
/*                                                                            */
/*  読み込んだデータをＵＤＰデータパケットで固定ＩＰのアドレスに送信します。  */
/*                                                                            */
/*  読み込んだデータはＳＤカードにログファイル(HID-USB_log.CSV)に記録します。 */
/*                                                                            */
/*                                                                            */
/*                                                                            */
/*                                                                            */
/*                                                                            */
/*                                                                            */
/*                                                                            */
/*                                                                            */
/*                                                                            */
/*                                                                            */
/* 【特記事項】                                                               */
/*                                                                            */
/*  このソースコードにはネット上で公開されている資料を使っています。          */
/*                                                                            */
/*  出展元は本誌を参照して下さい。                                            */
/*                                                                            */
/*                               Copyright(c)  2012  by  Yoshirou Ishigami    */
/*                                                                            */
/******************************************************************************/

                                                 /*                           */
package sample;                      /*                           */
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.FileWriter;
import java.io.IOException;
import java.io.OutputStreamWriter;
import java.io.PrintWriter;
import java.io.UnsupportedEncodingException;
import java.text.SimpleDateFormat;               /*                           */
import java.util.Date;

import android.annotation.SuppressLint;          /*                           */
import android.content.BroadcastReceiver;        /*                           */
import android.content.Context;                  /*                           */
import android.content.Intent;                   /*                           */
import android.content.SharedPreferences;        /*                           */
import android.os.Environment;
import android.widget.Toast;                     /*                           */
                                                 /*                           */
@SuppressLint("CommitPrefEdits")
public class AlarmReceiver extends BroadcastReceiver
{                                                /*                           */
     @Override                                   /*                           */
     public void onReceive(                      /*                           */
             Context context , Intent intent )   /*                           */
      {                                          /*                           */
/*----------------------------------------------------------------------------*/
/*-             共有ファイルを開いてメインからの情報を格納する。             -*/
/*----------------------------------------------------------------------------*/
                                                 /*                           */
       SharedPreferences get_data  =             /* 共有ファイルの名称をセット*/
           context.getSharedPreferences(         /* する。                    */
                  "HID-USB_preferences" ,        /* 名称 HID-USB_preferences  */
                  Context.MODE_WORLD_READABLE ); /* 読み込みは自由モード      */
                                                 /*                           */
       int sd_check = get_data.getInt(           /* ＳＤカードの装着状態を格納*/
                             "SD_CHECK",  -1  ); /* する。                    */
                                                 /*                           */
       String  edit_data = get_data.getString(   /* 文字入力欄のデータを格納す*/
                           "EDIT_DATA" , "-" ) ; /* る。※メインからの引継ぎ。*/
                                                 /*                           */
                                                 /*                           */
       String  log_file = get_data.getString(    /* ログファイルの名称を格納  */
                           "LOG_FILE" , "-" ) ;  /* る。※メインからの引継ぎ。*/
                                                 /*                           */
/*----------------------------------------------------------------------------*/
/*-               ＳＤカードが実装されている場合の処理をする。               -*/
/*----------------------------------------------------------------------------*/
                                                 /*                           */
       if( sd_check == 1 )                       /* ＳＤカード着装有りか?     */
        {                                        /* はい。                    */
/*----------------------------------------------------------------------------*/
/*-            データの記録時間を「時：分：秒」の様式で編集する。            -*/
/*----------------------------------------------------------------------------*/
                                                 /*                           */
         Date now = new Date();                  /* 現在の時刻を格納する。    */
                                                 /*                           */
         SimpleDateFormat sdfmt  =               /* 時刻の編集書式を格納する。*/
                    new SimpleDateFormat(        /*        "                  */
                                  "k:mm:ss" ) ;  /* ※時:分:秒の様式          */
                                                 /*                           */
         String fmt_Time = sdfmt.format( now ) ; /* 時刻を文字列に格納する。  */
                                                 /*                           */
         String edit_String =  fmt_Time  +       /* 記入データを１行に編集。  */
                               ","       +       /* ※.csv型式の書式です。    */
                               edit_data +       /*          "                */
                               "\n"        ;     /*          "                */
                                                 /*                           */
/*----------------------------------------------------------------------------*/
/*-             時刻と受信データの文字列をＳＤカードへ記録する。             -*/
/*-                                                                          -*/
/*-  ☆ 記入データはcsv型式で１行に編集されています。                        -*/
/*-                                                                          -*/
/*----------------------------------------------------------------------------*/
                                                 /*                           */
         if( log_file  !=  "-"  )                /* ログファイル名は有効か？  */
          {                                      /* はい。                    */
           try                                   /* エラーを伴う処理の実行    */
            {                                    /*                           */
             FileWriter writer =                 /* ファイルライタを準備。    */
                  new FileWriter( log_file  ,    /* ※ファイル名を指定する。  */
                                      true  ) ;  /*                           */
                                                 /*                           */
             writer.write( edit_String ) ;       /* ファイルへ書き込みをする。*/
                                                 /*                           */
             writer.close();                     /* 書き込みを終了する。      */
                                                 /*                           */
            }                                    /*                           */
           catch (IOException e)                 /* エラー時の処理。          */
            {                                    /*                           */
             e.printStackTrace();                /*                           */
            }                                    /*                           */
                                                 /*                           */
          }                                      /*                           */
                                                 /*                           */
         Toast.makeText(                         /* メッセージを表示する。    */
                     context  ,                  /*          "                */
                     fmt_Time +                  /*          "                */
                     ","      +                  /*          "                */
                     edit_data ,                 /*          "                */
                     Toast.LENGTH_LONG ).show(); /* 表示時間は長く。          */
        }                                        /*                           */
                                                 /*                           */
      }                                          /*                           */
                                                 /*                           */
}                                                /*                           */
/******************************************************************************/
